@@ -42,7 +42,7 @@ class Foreperson:
         self.q_step = None
         self.q_shape = 'linear'
         self.n_columns = 3
-        self.theta_axis_name = None
+        self.theta_axis_name = "dcdtheta"
         self.q_axis_name = "qdcd"
         self.transpose = False
         self.qz_dimension = 1
